==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/Badge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { BadgeVariant_$type } from "./BadgeVariant";
import { BadgeShape_$type } from "./BadgeShape";
/**
 * @hidden
 */
var Badge = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Badge, _super);
    function Badge() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(Badge.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Badge.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.c.n = this.f;
        },
        enumerable: false,
        configurable: true
    });
    Badge.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Badge.prototype, "b", {
        get: function () {
            var ret_ = this.d.m("variant");
            ret_ = enumGetBox(BadgeVariant_$type, EnumUtil.getEnumValue(BadgeVariant_$type, this.d.f(BadgeVariant_$type, ret_)));
            return EnumUtil.getEnumValue(BadgeVariant_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(BadgeVariant_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.d.u("variant", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Badge.prototype, "e", {
        get: function () {
            var ret_ = this.d.m("outlined");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.u("outlined", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Badge.prototype, "a", {
        get: function () {
            var ret_ = this.d.m("shape");
            ret_ = enumGetBox(BadgeShape_$type, EnumUtil.getEnumValue(BadgeShape_$type, this.d.f(BadgeShape_$type, ret_)));
            return EnumUtil.getEnumValue(BadgeShape_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(BadgeShape_$type, a);
            value_ = WCNativeHelper.o(value_.toString());
            this.d.u("shape", value_);
        },
        enumerable: false,
        configurable: true
    });
    Badge.$t = markType(Badge, 'Badge', BaseElement.$);
    return Badge;
}(BaseElement));
export { Badge };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/Badge.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { BadgeVariant_$type } from "./BadgeVariant";
import { BadgeShape_$type } from "./BadgeShape";
/**
 * @hidden
 */
var Badge = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(Badge, _super);
    function Badge() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.c = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(Badge.prototype, "d", {
        get: function () {
            return this.c;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Badge.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.c.o = this.f;
        },
        enumerable: false,
        configurable: true
    });
    Badge.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(Badge.prototype, "b", {
        get: function () {
            var ret_ = this.d.n("variant");
            ret_ = enumGetBox(BadgeVariant_$type, EnumUtil.getEnumValue(BadgeVariant_$type, this.d.f(BadgeVariant_$type, ret_)));
            return EnumUtil.getEnumValue(BadgeVariant_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(BadgeVariant_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.d.v("variant", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Badge.prototype, "e", {
        get: function () {
            var ret_ = this.d.n("outlined");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.d.v("outlined", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Badge.prototype, "a", {
        get: function () {
            var ret_ = this.d.n("shape");
            ret_ = enumGetBox(BadgeShape_$type, EnumUtil.getEnumValue(BadgeShape_$type, this.d.f(BadgeShape_$type, ret_)));
            return EnumUtil.getEnumValue(BadgeShape_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(BadgeShape_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.d.v("shape", value_);
        },
        enumerable: false,
        configurable: true
    });
    Badge.$t = markType(Badge, 'Badge', BaseElement.$);
    return Badge;
}(BaseElement));
export { Badge };
